![Pulp CI](https://github.com/pulp/pulp_ostree/workflows/Pulp%20CI/badge.svg)

Pulp OSTree Plugin
==================

A Pulp plugin to support hosting your own OSTree.

For more information, please see the [documentation](docs/index.rst) or the [Pulp project page](https://pulpproject.org/).

How to File an Issue
--------------------


Visit [our tracker](https://pulp.plan.io/projects/pulp_ostree/issues/new) to file a `pulp_ostree` issue.


> **WARNING** Is this security related? If so, please follow the [Security Disclosures](https://docs.pulpproject.org/pulpcore/bugs-features.html#security-bugs) procedure.


Please set **only the fields in this table**. See [Redmine Fields](https://docs.pulpproject.org/pulpcore/bugs-features.html#redmine-fields) for more detailed
descriptions of all the fields and how they are used.

| Field | Instructions |
| ----- | ----------- |
| Tracker | For a bug, select `Issue`, for a feature-request, choose `Story` |
| Subject | Strive to be specific and concise. |
| Description | This is the most important part! Please see [Description Field](https://docs.pulpproject.org/bugs-features.html#issue-description). |
| Category | Choose one if applicable, blank is OK. |
| Version | The version of pulp-ostree that you discovered the issue. |
| OS | Please select your operating system. |
| Tags | For searching. Select 0 or many, best judgement. |

